==> freecad_0.17%2Bdfsg1.orig.tar.gz: FreeCAD-0.17/src/Mod/ReverseEngineering/Gui/Resources/translations/ReverseEngineering_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="el" sourcelanguage="en">
  <context>
    <name>CmdApproxPlane</name>
    <message>
      <location filename="../../Command.cpp" line="+93"/>
      <source>Reverse Engineering</source>
      <translation type="unfinished">Reverse Engineering</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate plane...</source>
      <translation>Πλάνο κατά προσέγγιση...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate a plane</source>
      <translation>Πλάνο κατά προσέγγιση</translation>
    </message>
  </context>
  <context>
    <name>CmdApproxSurface</name>
    <message>
      <location line="-37"/>
      <source>Reverse Engineering</source>
      <translation type="unfinished">Reverse Engineering</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate B-spline surface...</source>
      <translation type="unfinished">Approximate B-spline surface...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate a B-spline surface</source>
      <translation type="unfinished">Approximate a B-spline surface</translation>
    </message>
    <message>
      <source>Approximate B-Spline surface...</source>
      <translation>Κατά προσέγγιση επιφάνεια B-Spline...</translation>
    </message>
    <message>
      <source>Approximate surface...</source>
      <translation>Κατά προσέγγιση επιφάνεια...</translation>
    </message>
    <message>
      <source>Approximate a B-Spline surface</source>
      <translation>Κατά προσέγγιση ένα B-Spline επιφάνεια</translation>
    </message>
  </context>
  <context>
    <name>CmdPoissonReconstruction</name>
    <message>
      <location line="+134"/>
      <source>Reverse Engineering</source>
      <translation type="unfinished">Reverse Engineering</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Poisson...</source>
      <translation>Poisson...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Poisson surface reconstruction</source>
      <translation>Poisson επιφάνειας ανασυγκρότησης</translation>
    </message>
  </context>
  <context>
    <name>CmdViewTriangulation</name>
    <message>
      <location line="+32"/>
      <source>Reverse Engineering</source>
      <translation type="unfinished">Reverse Engineering</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Structured point clouds</source>
      <translation type="unfinished">Structured point clouds</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+1"/>
      <source>Triangulation of structured point clouds</source>
      <translation type="unfinished">Triangulation of structured point clouds</translation>
    </message>
    <message>
      <source>View triangulation</source>
      <translation type="unfinished">View triangulation</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::FitBSplineSurface</name>
    <message>
      <source>Fit B-Spline surface</source>
      <translation type="unfinished">Fit B-Spline surface</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="+14"/>
      <source>Fit B-spline surface</source>
      <translation type="unfinished">Fit B-spline surface</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>u-Direction</source>
      <translation type="unfinished">u-Direction</translation>
    </message>
    <message>
      <location line="+6"/>
      <location line="+67"/>
      <source>Degree</source>
      <translation type="unfinished">Degree</translation>
    </message>
    <message>
      <location line="-38"/>
      <location line="+67"/>
      <source>Control points</source>
      <translation>Σημεία ελέγχου</translation>
    </message>
    <message>
      <location line="-35"/>
      <source>v-Direction</source>
      <translation>v-κατεύθυνση</translation>
    </message>
    <message>
      <location line="+67"/>
      <source>Settings</source>
      <translation type="unfinished">Settings</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Iterations</source>
      <translation>Επαναλήψεις</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Size factor</source>
      <translation>Μέγεθος παράγοντας</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Smoothing</source>
      <translation>Εξομάλυνση</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Total Weight</source>
      <translation type="unfinished">Total Weight</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Length of gradient</source>
      <translation type="unfinished">Length of gradient</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Bending energy</source>
      <translation type="unfinished">Bending energy</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Curvature variation</source>
      <translation type="unfinished">Curvature variation</translation>
    </message>
    <message>
      <location line="+32"/>
      <source>User-defined u/v directions</source>
      <translation type="unfinished">User-defined u/v directions</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::FitBSplineSurfaceWidget</name>
    <message>
      <location filename="../../FitBSplineSurface.cpp" line="+146"/>
      <source>Wrong selection</source>
      <translation>Λάθος επιλογή</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Please select a single placement object to get local orientation.</source>
      <translation type="unfinished">Please select a single placement object to get local orientation.</translation>
    </message>
    <message>
      <location line="+28"/>
      <source>Input error</source>
      <translation>Σφάλμα εισαγωγής</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::PoissonWidget</name>
    <message>
      <location filename="../../Poisson.ui" line="+14"/>
      <source>Poisson</source>
      <translation type="unfinished">Poisson</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Parameters</source>
      <translation type="unfinished">Parameters</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Octree depth</source>
      <translation type="unfinished">Octree depth</translation>
    </message>
    <message>
      <location line="+20"/>
      <source>Solver divide</source>
      <translation type="unfinished">Solver divide</translation>
    </message>
    <message>
      <location line="+20"/>
      <source>Samples per node</source>
      <translation type="unfinished">Samples per node</translation>
    </message>
    <message>
      <location filename="../../Poisson.cpp" line="+109"/>
      <source>Input error</source>
      <translation>Σφάλμα εισαγωγής</translation>
    </message>
  </context>
  <context>
    <name>Reen_ApproxSurface</name>
    <message>
      <location filename="../../Command.cpp" line="-159"/>
      <location line="+135"/>
      <source>Wrong selection</source>
      <translation>Λάθος επιλογή</translation>
    </message>
    <message>
      <location line="-134"/>
      <location line="+135"/>
      <source>Please select a single point cloud.</source>
      <translation type="unfinished">Please select a single point cloud.</translation>
    </message>
  </context>
  <context>
    <name>Reen_ViewTriangulation</name>
    <message>
      <location line="+55"/>
      <source>View triangulation failed</source>
      <translation type="unfinished">View triangulation failed</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+37"/>
      <source>Reverse Engineering</source>
      <translation type="unfinished">Reverse Engineering</translation>
    </message>
  </context>
</TS>

==> freecad_0.18~pre1%2Bdfsg1.orig.tar.gz: FreeCAD-0.18_pre/src/Mod/ReverseEngineering/Gui/Resources/translations/ReverseEngineering_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="el" sourcelanguage="en">
  <context>
    <name>CmdApproxPlane</name>
    <message>
      <location filename="../../Command.cpp" line="+93"/>
      <source>Reverse Engineering</source>
      <translation>Αντίστροφη Μηχανική</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate plane...</source>
      <translation>Προσέγγιση επιπέδου...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate a plane</source>
      <translation>Προσέγγιση ενός επιπέδου</translation>
    </message>
  </context>
  <context>
    <name>CmdApproxSurface</name>
    <message>
      <location line="-37"/>
      <source>Reverse Engineering</source>
      <translation>Αντίστροφη Μηχανική</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate B-spline surface...</source>
      <translation>Προσέγγιση επιφάνειας B-spline...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate a B-spline surface</source>
      <translation>Προσέγγιση μιας επιφάνειας B-spline</translation>
    </message>
    <message>
      <source>Approximate B-Spline surface...</source>
      <translation>Προσέγγιση επιφάνειας B-Spline...</translation>
    </message>
    <message>
      <source>Approximate surface...</source>
      <translation>Κατά προσέγγιση επιφάνεια...</translation>
    </message>
    <message>
      <source>Approximate a B-Spline surface</source>
      <translation>Προσέγγιση μιας επιφάνειας B-Spline</translation>
    </message>
  </context>
  <context>
    <name>CmdPoissonReconstruction</name>
    <message>
      <location line="+134"/>
      <source>Reverse Engineering</source>
      <translation>Αντίστροφη Μηχανική</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Poisson...</source>
      <translation>Poisson...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Poisson surface reconstruction</source>
      <translation>Ανακατασκευή επιφάνειας Poisson</translation>
    </message>
  </context>
  <context>
    <name>CmdViewTriangulation</name>
    <message>
      <location line="+32"/>
      <source>Reverse Engineering</source>
      <translation>Αντίστροφη Μηχανική</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Structured point clouds</source>
      <translation>Δομημένα νέφη σημείων</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+1"/>
      <source>Triangulation of structured point clouds</source>
      <translation>Τριγωνισμός των δομημένων νεφών σημείων</translation>
    </message>
    <message>
      <source>View triangulation</source>
      <translation type="unfinished">View triangulation</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::FitBSplineSurface</name>
    <message>
      <source>Fit B-Spline surface</source>
      <translation>Προσαρμογή στην επιφάνεια B-Spline</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="+14"/>
      <source>Fit B-spline surface</source>
      <translation>Προσαρμογή στην επιφάνεια B-spline</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>u-Direction</source>
      <translation>Διεύθυνση u</translation>
    </message>
    <message>
      <location line="+6"/>
      <location line="+67"/>
      <source>Degree</source>
      <translation>Βαθμός</translation>
    </message>
    <message>
      <location line="-38"/>
      <location line="+67"/>
      <source>Control points</source>
      <translation>Σημεία ελέγχου</translation>
    </message>
    <message>
      <location line="-35"/>
      <source>v-Direction</source>
      <translation>Διεύθυνση v</translation>
    </message>
    <message>
      <location line="+67"/>
      <source>Settings</source>
      <translation type="unfinished">Settings</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Iterations</source>
      <translation>Επαναλήψεις</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Size factor</source>
      <translation>Παράγοντας μεγέθους</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Smoothing</source>
      <translation>Εξομάλυνση</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Total Weight</source>
      <translation>Συνολικό Βάρος</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Length of gradient</source>
      <translation>Μήκος βαθμίδας</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Bending energy</source>
      <translation>Ενέργεια κάμψης</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Curvature variation</source>
      <translation>Μεταβολή καμπυλότητας</translation>
    </message>
    <message>
      <location line="+32"/>
      <source>User-defined u/v directions</source>
      <translation>Κατευθύνσεις u/v ορισμένες από τον χρήστη</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::FitBSplineSurfaceWidget</name>
    <message>
      <location filename="../../FitBSplineSurface.cpp" line="+146"/>
      <source>Wrong selection</source>
      <translation>Λάθος επιλογή</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Please select a single placement object to get local orientation.</source>
      <translation>Παρακαλώ επιλέξτε ένα αντικείμενο τοποθέτησης για να έχετε τον τοπικό προσανατολισμό.</translation>
    </message>
    <message>
      <location line="+28"/>
      <source>Input error</source>
      <translation>Σφάλμα εισαγωγής</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::PoissonWidget</name>
    <message>
      <location filename="../../Poisson.ui" line="+14"/>
      <source>Poisson</source>
      <translation>Poisson</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Parameters</source>
      <translation>Παράμετροι</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Octree depth</source>
      <translation>Βάθος οκταδικού δένδρου</translation>
    </message>
    <message>
      <location line="+20"/>
      <source>Solver divide</source>
      <translation>Διαίρεση του επιλυτή</translation>
    </message>
    <message>
      <location line="+20"/>
      <source>Samples per node</source>
      <translation>Δείγματα ανά κόμβο</translation>
    </message>
    <message>
      <location filename="../../Poisson.cpp" line="+109"/>
      <source>Input error</source>
      <translation>Σφάλμα εισαγωγής</translation>
    </message>
  </context>
  <context>
    <name>Reen_ApproxSurface</name>
    <message>
      <location filename="../../Command.cpp" line="-159"/>
      <location line="+135"/>
      <source>Wrong selection</source>
      <translation>Λάθος επιλογή</translation>
    </message>
    <message>
      <location line="-134"/>
      <location line="+135"/>
      <source>Please select a single point cloud.</source>
      <translation>Παρακαλώ επιλέξτε ένα νέφος σημείων.</translation>
    </message>
  </context>
  <context>
    <name>Reen_ViewTriangulation</name>
    <message>
      <location line="+55"/>
      <source>View triangulation failed</source>
      <translation>Η προβολή τριγωνισμού απέτυχε</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+37"/>
      <source>Reverse Engineering</source>
      <translation>Αντίστροφη Μηχανική</translation>
    </message>
  </context>
</TS>
